@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BT_KEEP_ALIVE_MESSAGE_H_
-#define _D_BT_KEEP_ALIVE_MESSAGE_H_
+#ifndef D_BT_KEEP_ALIVE_MESSAGE_H
+#define D_BT_KEEP_ALIVE_MESSAGE_H
 
 #include "SimpleBtMessage.h"
 
@@ -45,15 +45,9 @@ typedef SharedHandle<BtKeepAliveMessage> BtKeepAliveMessageHandle;
 
 class BtKeepAliveMessage : public SimpleBtMessage {
 private:
-  unsigned char* msg;
-
   static const size_t MESSAGE_LENGTH = 4;
 public:
-  BtKeepAliveMessage():SimpleBtMessage(ID, NAME), msg(0) {}
-
-  virtual ~BtKeepAliveMessage() {
-    delete [] msg;
-  }
+  BtKeepAliveMessage():SimpleBtMessage(ID, NAME) {}
 
   static const uint8_t ID = 99;
 
@@ -61,15 +55,16 @@ public:
 
   virtual void doReceivedAction() {}
 
-  virtual const unsigned char* getMessage();
+  virtual unsigned char* createMessage();
 
   virtual size_t getMessageLength();
 
-  virtual std::string toString() const {
+  virtual std::string toString() const
+  {
     return NAME;
   }
 };
 
 } // namespace aria2
 
-#endif // _D_BT_KEEP_ALIVE_MESSAGE_H_
+#endif // D_BT_KEEP_ALIVE_MESSAGE_H
