@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BT_SEEDER_STATE_CHOKE_H_
-#define _D_BT_SEEDER_STATE_CHOKE_H_
+#ifndef D_BT_SEEDER_STATE_CHOKE_H
+#define D_BT_SEEDER_STATE_CHOKE_H
 
 #include "common.h"
 
@@ -102,4 +102,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_BT_SEEDER_STATE_CHOKE_H_
+#endif // D_BT_SEEDER_STATE_CHOKE_H
