@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,87 +32,94 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_CHUNK_CHECKSUM_H_
-#define _D_CHUNK_CHECKSUM_H_
+#ifndef D_CHUNK_CHECKSUM_H
+#define D_CHUNK_CHECKSUM_H
 
 #include "common.h"
-#include "messageDigest.h"
+
+#include <string>
+#include <vector>
+
+#include "SharedHandle.h"
+#include "A2STR.h"
+
+namespace aria2 {
 
 class ChunkChecksum {
 private:
-  string _algo;
-  Strings _checksums;
-  int32_t _checksumLength;
+  std::string algo_;
+  std::vector<std::string> checksums_;
+  size_t checksumLength_;
 public:
-  ChunkChecksum():_checksumLength(0) {}    
+  ChunkChecksum():checksumLength_(0) {}    
 
-  ChunkChecksum(const string& algo,
-		const Strings& checksums,
-		int32_t checksumLength):
-    _algo(algo),
-    _checksums(checksums),
-    _checksumLength(checksumLength) {}
+  ChunkChecksum(const std::string& algo,
+                const std::vector<std::string>& checksums,
+                size_t checksumLength):
+    algo_(algo),
+    checksums_(checksums),
+    checksumLength_(checksumLength) {}
 
-  bool validateChunk(const string& actualChecksum,
-		     int32_t checksumIndex) const
+  bool validateChunk(const std::string& actualChecksum,
+                     size_t checksumIndex) const
   {
-    if(checksumIndex < (int32_t)_checksums.size()) {
+    if(checksumIndex < checksums_.size()) {
       return actualChecksum == getChecksum(checksumIndex);
     } else {
       return false;
     }
   }
 
-  int64_t getEstimatedDataLength() const
+  uint64_t getEstimatedDataLength() const
   {
-    return ((int64_t)_checksumLength)*_checksums.size();
+    return ((uint64_t)checksumLength_)*checksums_.size();
   }
 
-  int32_t countChecksum() const
+  size_t countChecksum() const
   {
-    return _checksums.size();
+    return checksums_.size();
   }
 
-  string getChecksum(int32_t index) const
+  const std::string& getChecksum(size_t index) const
   {
-    if(index < (int32_t)_checksums.size()) {
-      return _checksums[index];
+    if(index < checksums_.size()) {
+      return checksums_[index];
     } else {
-      return "";
+      return A2STR::NIL;
     }
   }
   
-  const Strings& getChecksums() const
+  const std::vector<std::string>& getChecksums() const
   {
-    return _checksums;
+    return checksums_;
   }
 
-  int32_t getChecksumLength() const
+  size_t getChecksumLength() const
   {
-    return _checksumLength;
+    return checksumLength_;
   }
 
-  const string& getAlgo() const
+  const std::string& getAlgo() const
   {
-    return _algo;
+    return algo_;
   }
 
-  void setAlgo(const string& algo)
+  void setAlgo(const std::string& algo)
   {
-    _algo = algo;
+    algo_ = algo;
   }
 
-  void setChecksumLength(int32_t length)
+  void setChecksumLength(size_t length)
   {
-    _checksumLength = length;
+    checksumLength_ = length;
   }
 
-  void setChecksums(const Strings& mds)
+  void setChecksums(const std::vector<std::string>& mds)
   {
-    _checksums = mds;
+    checksums_ = mds;
   }
 };
 
-typedef SharedHandle<ChunkChecksum> ChunkChecksumHandle;
+} // namespace aria2
 
-#endif // _D_CHUNK_CHECKSUM_H_
+#endif // D_CHUNK_CHECKSUM_H
