@@ -32,31 +32,31 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DHT_NODE_H_
-#define _D_DHT_NODE_H_
+#ifndef D_DHT_NODE_H
+#define D_DHT_NODE_H
 
 #include "common.h"
 #include "SharedHandle.h"
 #include "DHTConstants.h"
-#include "TimeA2.h"
+#include "TimerA2.h"
 #include <string>
 
 namespace aria2 {
 
 class DHTNode {
 private:
-  unsigned char _id[DHT_ID_LENGTH];
+  unsigned char id_[DHT_ID_LENGTH];
 
-  std::string _ipaddr;
+  std::string ipaddr_;
 
-  uint16_t _port;
+  uint16_t port_;
 
   // in milli sec
-  unsigned int _rtt;
+  unsigned int rtt_;
 
-  unsigned int _condition;
+  unsigned int condition_;
 
-  Time _lastContact;
+  Timer lastContact_;
 public:
   DHTNode();
   
@@ -69,34 +69,34 @@ public:
 
   const unsigned char* getID() const
   {
-    return _id;
+    return id_;
   }
 
   void updateRTT(unsigned int millisec)
   {
-    _rtt = millisec;
+    rtt_ = millisec;
   }
 
-  std::string getIPAddress() const
+  const std::string& getIPAddress() const
   {
-    return _ipaddr;
+    return ipaddr_;
   }
 
   void setIPAddress(const std::string& ipaddr)
   {
-    _ipaddr = ipaddr;
+    ipaddr_ = ipaddr;
   }
 
   void setID(const unsigned char* id);
 
   uint16_t getPort() const
   {
-    return _port;
+    return port_;
   }
 
   void setPort(uint16_t port)
   {
-    _port = port;
+    port_ = port;
   }
 
   bool isGood() const;
@@ -122,4 +122,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_DHT_NODE_H_
+#endif // D_DHT_NODE_H
