@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DHT_ROUTING_TABLE_DESERIALIZER_H_
-#define _D_DHT_ROUTING_TABLE_DESERIALIZER_H_
+#ifndef D_DHT_ROUTING_TABLE_DESERIALIZER_H
+#define D_DHT_ROUTING_TABLE_DESERIALIZER_H
 
 #include "common.h"
 
@@ -81,4 +81,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_DHT_ROUTING_TABLE_DESERIALIZER_H_
+#endif // D_DHT_ROUTING_TABLE_DESERIALIZER_H
