@@ -140,6 +140,7 @@ void DefaultBtMessageDispatcher::doCancelSendingPieceAction
 {
 }
 
+namespace {
 class AbortOutstandingRequest {
 private:
   SharedHandle<Piece> piece_;
@@ -156,13 +157,14 @@ public:
     if(logger_->debug()) {
       logger_->debug(MSG_DELETING_REQUEST_SLOT,
                      util::itos(cuid_).c_str(),
-                     slot.getIndex(),
-                     slot.getBlockIndex());
-      logger_->debug("index=%d, begin=%d", slot.getIndex(), slot.getBegin());
+                     static_cast<unsigned long>(slot.getIndex()),
+                     slot.getBegin(),
+                     static_cast<unsigned long>(slot.getBlockIndex()));
     }
     piece_->cancelBlock(slot.getBlockIndex());
   }
 };
+} // namespace
 
 // localhost cancels outstanding download requests to the peer.
 void DefaultBtMessageDispatcher::doAbortOutstandingRequestAction
@@ -186,6 +188,7 @@ void DefaultBtMessageDispatcher::doAbortOutstandingRequestAction
                   &BtMessage::onAbortOutstandingRequestEvent, event);
 }
 
+namespace {
 class ProcessChokedRequestSlot {
 private:
   cuid_t cuid_;
@@ -207,9 +210,9 @@ public:
       if(logger_->debug()) {
         logger_->debug(MSG_DELETING_REQUEST_SLOT_CHOKED,
                        util::itos(cuid_).c_str(),
-                       slot.getIndex(),
-                       slot.getBlockIndex());
-        logger_->debug("index=%d, begin=%d", slot.getIndex(), slot.getBegin());
+                       static_cast<unsigned long>(slot.getIndex()),
+                       slot.getBegin(),
+                       static_cast<unsigned long>(slot.getBlockIndex()));
       }
       SharedHandle<Piece> piece = pieceStorage_->getPiece(slot.getIndex());
       piece->cancelBlock(slot.getBlockIndex());
@@ -217,7 +220,9 @@ public:
   }
 
 };
+} // namespace
 
+namespace {
 class FindChokedRequestSlot {
 private:
   SharedHandle<Peer> peer_;
@@ -230,6 +235,7 @@ public:
     return !peer_->isInPeerAllowedIndexSet(slot.getIndex());
   }
 };
+} // namespace
 
 // localhost received choke message from the peer.
 void DefaultBtMessageDispatcher::doChokedAction()
@@ -253,6 +259,7 @@ void DefaultBtMessageDispatcher::doChokingAction()
                   &BtMessage::onChokingEvent, event);
 }
 
+namespace {
 class ProcessStaleRequestSlot {
 private:
   cuid_t cuid_;
@@ -282,8 +289,9 @@ public:
       if(logger_->debug()) {
         logger_->debug(MSG_DELETING_REQUEST_SLOT_TIMEOUT,
                        util::itos(cuid_).c_str(),
-                       slot.getBlockIndex());
-        logger_->debug("index=%d, begin=%d", slot.getIndex(), slot.getBegin());
+                       static_cast<unsigned long>(slot.getIndex()),
+                       slot.getBegin(),
+                       static_cast<unsigned long>(slot.getBlockIndex()));
       }
       slot.getPiece()->cancelBlock(slot.getBlockIndex());
       peer_->snubbing(true);
@@ -291,8 +299,9 @@ public:
       if(logger_->debug()) {
         logger_->debug(MSG_DELETING_REQUEST_SLOT_ACQUIRED,
                        util::itos(cuid_).c_str(),
-                       slot.getBlockIndex());
-        logger_->debug("index=%d, begin=%d", slot.getIndex(), slot.getBegin());
+                       static_cast<unsigned long>(slot.getIndex()),
+                       slot.getBegin(),
+                       static_cast<unsigned long>(slot.getBlockIndex()));
       }
       messageDispatcher_->addMessageToQueue
         (messageFactory_->createCancelMessage(slot.getIndex(),
@@ -301,7 +310,9 @@ public:
     }
   }
 };
+} // namespace
 
+namespace {
 class FindStaleRequestSlot {
 private:
   SharedHandle<PieceStorage> pieceStorage_;
@@ -325,6 +336,7 @@ public:
     }
   }
 };
+} // namespace
 
 void DefaultBtMessageDispatcher::checkRequestSlotAndDoNecessaryThing()
 {
@@ -350,6 +362,7 @@ bool DefaultBtMessageDispatcher::isSendingInProgress()
   }
 }
 
+namespace {
 class BlockIndexLess {
 public:
   bool operator()(const RequestSlot& lhs, const RequestSlot& rhs) const
@@ -361,6 +374,7 @@ public:
     }
   }
 };
+} // namespace
 
 bool DefaultBtMessageDispatcher::isOutstandingRequest
 (size_t index, size_t blockIndex) {
