@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,15 +32,19 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DEFAULT_BT_MESSAGE_DISPATCHER_H_
-#define _D_DEFAULT_BT_MESSAGE_DISPATCHER_H_
+#ifndef D_DEFAULT_BT_MESSAGE_DISPATCHER_H
+#define D_DEFAULT_BT_MESSAGE_DISPATCHER_H
 
 #include "BtMessageDispatcher.h"
+
+#include <deque>
+
 #include "a2time.h"
+#include "Command.h"
 
 namespace aria2 {
 
-class BtContext;
+class DownloadContext;
 class PeerStorage;
 class PieceStorage;
 class BtMessage;
@@ -52,19 +56,17 @@ class RequestGroupMan;
 
 class DefaultBtMessageDispatcher : public BtMessageDispatcher {
 private:
-  int32_t cuid;
-  std::deque<SharedHandle<BtMessage> > messageQueue;
-  std::deque<RequestSlot> requestSlots;
-  SharedHandle<BtContext> btContext;
-  SharedHandle<PeerStorage> _peerStorage;
-  SharedHandle<PieceStorage> _pieceStorage;
-  WeakHandle<BtMessageFactory> messageFactory;
-  SharedHandle<Peer> peer;
-  WeakHandle<RequestGroupMan> _requestGroupMan;
-  unsigned int _maxOverallSpeedLimit;
-  unsigned int _maxUploadSpeedLimit;
-  time_t requestTimeout;
-  Logger* logger;
+  cuid_t cuid;
+  std::deque<SharedHandle<BtMessage> > messageQueue_;
+  std::deque<RequestSlot> requestSlots_;
+  SharedHandle<DownloadContext> downloadContext_;
+  SharedHandle<PeerStorage> peerStorage_;
+  SharedHandle<PieceStorage> pieceStorage_;
+  WeakHandle<BtMessageFactory> messageFactory_;
+  SharedHandle<Peer> peer_;
+  WeakHandle<RequestGroupMan> requestGroupMan_;
+  time_t requestTimeout_;
+  Logger* logger_;
 public:
   DefaultBtMessageDispatcher();
 
@@ -72,7 +74,8 @@ public:
   
   virtual void addMessageToQueue(const SharedHandle<BtMessage>& btMessage);
 
-  virtual void addMessageToQueue(const std::deque<SharedHandle<BtMessage> >& btMessages);
+  virtual void addMessageToQueue
+  (const std::vector<SharedHandle<BtMessage> >& btMessages);
 
   virtual void sendMessages();
 
@@ -91,11 +94,14 @@ public:
   virtual bool isSendingInProgress();
 
   virtual size_t countMessageInQueue() {
-    return messageQueue.size();
+    return messageQueue_.size();
   }
 
-  virtual size_t countOutstandingRequest();
-
+  virtual size_t countOutstandingRequest()
+  {
+    return requestSlots_.size();
+  }
+  
   virtual bool isOutstandingRequest(size_t index, size_t blockIndex);
 
   virtual RequestSlot getOutstandingRequest(size_t index, uint32_t begin, size_t length);
@@ -106,13 +112,19 @@ public:
 
   virtual size_t countOutstandingUpload();
 
-  const std::deque<SharedHandle<BtMessage> >& getMessageQueue();
+  const std::deque<SharedHandle<BtMessage> >& getMessageQueue() const
+  {
+    return messageQueue_;
+  }
 
-  const RequestSlots& getRequestSlots();
+  const std::deque<RequestSlot>& getRequestSlots() const
+  {
+    return requestSlots_;
+  }
 
   void setPeer(const SharedHandle<Peer>& peer);
 
-  void setBtContext(const SharedHandle<BtContext>& btContext);
+  void setDownloadContext(const SharedHandle<DownloadContext>& downloadContext);
 
   void setPieceStorage(const SharedHandle<PieceStorage>& pieceStorage);
 
@@ -122,22 +134,18 @@ public:
 
   void setRequestGroupMan(const WeakHandle<RequestGroupMan>& rgman);
 
-  void setCuid(int32_t cuid) {
+  void setCuid(cuid_t cuid)
+  {
     this->cuid = cuid;
   }
 
-  void setMaxUploadSpeedLimit(unsigned int maxUploadSpeedLimit);
-
-  void setMaxOverallSpeedLimit(unsigned int maxOverallSpeedLimit);
-
   void setRequestTimeout(time_t requestTimeout) {
-    this->requestTimeout = requestTimeout;
+    requestTimeout_ = requestTimeout;
   }
-
 };
 
 typedef SharedHandle<DefaultBtMessageDispatcher> DefaultBtMessageDispatcherHandle;
 
 } // namespace aria2
 
-#endif // _D_DEFAULT_BT_MESSAGE_DISPATCHER_H_
+#endif // D_DEFAULT_BT_MESSAGE_DISPATCHER_H
