@@ -66,13 +66,15 @@ namespace aria2 {
 const std::string DefaultBtProgressInfoFile::V0000("0000");
 const std::string DefaultBtProgressInfoFile::V0001("0001");
 
-static std::string createFilename
+namespace {
+std::string createFilename
 (const SharedHandle<DownloadContext>& dctx, const std::string& suffix)
 {
   std::string t = dctx->getBasePath();
   t += suffix;
   return t;
 }
+} // namespace
 
 DefaultBtProgressInfoFile::DefaultBtProgressInfoFile
 (const SharedHandle<DownloadContext>& dctx,
@@ -379,8 +381,9 @@ void DefaultBtProgressInfoFile::load()
       if(piece->getBitfieldLength() != bitfieldLength) {
         throw DL_ABORT_EX
           (StringFormat("piece bitfield length mismatch."
-                        " expected: %u actual: %u",
-                        piece->getBitfieldLength(), bitfieldLength).str());
+                        " expected: %lu actual: %u",
+                        static_cast<unsigned long>(piece->getBitfieldLength()),
+                        bitfieldLength).str());
       }
       array_ptr<unsigned char> pieceBitfield
         (new unsigned char[bitfieldLength]);
