@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DISK_ADAPTOR_H_
-#define _D_DISK_ADAPTOR_H_
+#ifndef D_DISK_ADAPTOR_H
+#define D_DISK_ADAPTOR_H
 
 #include "BinaryStream.h"
 
@@ -130,4 +130,4 @@ typedef SharedHandle<DiskAdaptor> DiskAdaptorHandle;
 
 } // namespace aria2
 
-#endif // _D_DISK_ADAPTOR_H_
+#endif // D_DISK_ADAPTOR_H
