@@ -32,15 +32,15 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DOWNLOAD_COMMAND_H_
-#define _D_DOWNLOAD_COMMAND_H_
+#ifndef D_DOWNLOAD_COMMAND_H
+#define D_DOWNLOAD_COMMAND_H
 
 #include "AbstractCommand.h"
 
 namespace aria2 {
 
-class Decoder;
 class PeerStat;
+class StreamFilter;
 #ifdef ENABLE_MESSAGE_DIGEST
 class MessageDigestContext;
 #endif // ENABLE_MESSAGE_DIGEST
@@ -53,10 +53,10 @@ private:
   unsigned int lowestDownloadSpeedLimit_;
   SharedHandle<PeerStat> peerStat_;
 
-#ifdef ENABLE_MESSAGE_DIGEST
-
   bool pieceHashValidationEnabled_;
 
+#ifdef ENABLE_MESSAGE_DIGEST
+
   SharedHandle<MessageDigestContext> messageDigestContext_;
 
 #endif // ENABLE_MESSAGE_DIGEST
@@ -67,9 +67,9 @@ private:
 
   void checkLowestDownloadSpeed() const;
 
-  SharedHandle<Decoder> transferEncodingDecoder_;
+  SharedHandle<StreamFilter> streamFilter_;
 
-  SharedHandle<Decoder> contentEncodingDecoder_;
+  bool sinkFilterOnly_;
 protected:
   virtual bool executeInternal();
 
@@ -86,19 +86,12 @@ public:
                   const SharedHandle<SocketCore>& s);
   virtual ~DownloadCommand();
 
-  const SharedHandle<Decoder>& getTransferEncodingDecoder() const
+  const SharedHandle<StreamFilter>& getStreamFilter() const
   {
-    return transferEncodingDecoder_;
+    return streamFilter_;
   }
 
-  void setTransferEncodingDecoder(const SharedHandle<Decoder>& decoder);
-
-  const SharedHandle<Decoder>& getContentEncodingDecoder() const
-  {
-    return contentEncodingDecoder_;
-  }
-
-  void setContentEncodingDecoder(const SharedHandle<Decoder>& decoder);
+  void installStreamFilter(const SharedHandle<StreamFilter>& streamFilter);
 
   void setStartupIdleTime(time_t startupIdleTime)
   {
@@ -113,4 +106,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_DOWNLOAD_COMMAND_H_
+#endif // D_DOWNLOAD_COMMAND_H
