@@ -32,24 +32,29 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_EXCEPTION_H_
-#define _D_EXCEPTION_H_
+#ifndef D_EXCEPTION_H
+#define D_EXCEPTION_H
 
 #include "common.h"
-#include "SharedHandle.h"
+
+#include <cerrno>
 #include <string>
 
+#include "SharedHandle.h"
+
 namespace aria2 {
 
 class Exception:public std::exception {
 private:
-  const char* _file;
+  const char* file_;
   
-  int _line;
+  int line_;
 
-  std::string _msg;
+  int errno_;
 
-  SharedHandle<Exception> _cause;
+  std::string msg_;
+
+  SharedHandle<Exception> cause_;
 
 protected:
   virtual SharedHandle<Exception> copy() const = 0;
@@ -62,13 +67,23 @@ public:
 
   Exception(const char* file, int line, const Exception& e);
 
+  Exception(const char* file, int line, int errnoArg, const std::string& msg);
+
   virtual ~Exception() throw();
 
-  virtual const char* what() const throw();
+  virtual const char* what() const throw()
+  {
+    return msg_.c_str();
+  }
 
-  std::string stackTrace() const throw();
+  std::string stackTrace() const;
+
+  int getErrno() const
+  {
+    return errno_;
+  }
 };
 
 } // namespace aria2
 
-#endif // _D_EXCEPTION_H_
+#endif // D_EXCEPTION_H
