@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_HTTP_HEADER_H_
-#define _D_HTTP_HEADER_H_
+#ifndef D_HTTP_HEADER_H
+#define D_HTTP_HEADER_H
 
 #include "common.h"
 
@@ -50,20 +50,20 @@ class Range;
 
 class HttpHeader {
 private:
-  std::multimap<std::string, std::string> table;
+  std::multimap<std::string, std::string> table_;
 
   // for HTTP response header only
   // response status, e.g. "200"
-  std::string _responseStatus;
+  std::string responseStatus_;
 
   // HTTP version, e.g. HTTP/1.1
-  std::string _version;
+  std::string version_;
 
   // HTTP Method, e.g. GET, POST, etc
-  std::string _method;
+  std::string method_;
 
   // Request Path
-  std::string _requestPath;
+  std::string requestPath_;
 public:
   HttpHeader() {}
   ~HttpHeader() {}
@@ -79,35 +79,35 @@ public:
 
   const std::string& getResponseStatus() const
   {
-    return _responseStatus;
+    return responseStatus_;
   }
 
   void setResponseStatus(const std::string& responseStatus);
 
   const std::string& getVersion() const
   {
-    return _version;
+    return version_;
   }
 
   void setVersion(const std::string& version);
 
   const std::string& getMethod() const
   {
-    return _method;
+    return method_;
   }
 
   void setMethod(const std::string& method);
 
   const std::string& getRequestPath() const
   {
-    return _requestPath;
+    return requestPath_;
   }
 
   void setRequestPath(const std::string& requestPath);
 
   void fill(std::istream& in);
 
-  // Clears table. _responseStatus and _version are unchanged.
+  // Clears table_. responseStatus_ and version_ are unchanged.
   void clearField();
 
   static const std::string LOCATION;
@@ -146,8 +146,20 @@ public:
 
   static const std::string S200;
 
+  static const std::string S206;
+
   static const std::string S300;
 
+  static const std::string S301;
+
+  static const std::string S302;
+
+  static const std::string S303;
+
+  static const std::string S304;
+
+  static const std::string S307;
+
   static const std::string S400;
 
   static const std::string S401;
@@ -159,4 +171,4 @@ typedef SharedHandle<HttpHeader> HttpHeaderHandle;
 
 } // namespace std;
 
-#endif // _D_HTTP_HEADER_H_
+#endif // D_HTTP_HEADER_H
