@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_HTTP_RESPONSE_H_
-#define _D_HTTP_RESPONSE_H_
+#ifndef D_HTTP_RESPONSE_H
+#define D_HTTP_RESPONSE_H
 
 #include "common.h"
 
@@ -48,7 +48,7 @@ namespace aria2 {
 class HttpRequest;
 class HttpHeader;
 class Logger;
-class Decoder;
+class StreamFilter;
 
 class HttpResponse {
 private:
@@ -86,13 +86,13 @@ public:
 
   std::string getTransferEncoding() const;
 
-  SharedHandle<Decoder> getTransferEncodingDecoder() const;
+  SharedHandle<StreamFilter> getTransferEncodingStreamFilter() const;
 
   bool isContentEncodingSpecified() const;
 
   const std::string& getContentEncoding() const;
 
-  SharedHandle<Decoder> getContentEncodingDecoder() const;
+  SharedHandle<StreamFilter> getContentEncodingStreamFilter() const;
 
   uint64_t getContentLength() const;
 
@@ -133,4 +133,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_HTTP_RESPONSE_H_
+#endif // D_HTTP_RESPONSE_H
