@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_HTTP_RESPONSE_COMMAND_H_
-#define _D_HTTP_RESPONSE_COMMAND_H_
+#ifndef D_HTTP_RESPONSE_COMMAND_H
+#define D_HTTP_RESPONSE_COMMAND_H
 
 #include "AbstractCommand.h"
 #include "TimeA2.h"
@@ -83,4 +83,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_HTTP_RESPONSE_COMMAND_H_
+#endif // D_HTTP_RESPONSE_COMMAND_H
