@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_LIBSSL_ARC4_DECRYPTOR_H_
-#define _D_LIBSSL_ARC4_DECRYPTOR_H_
+#ifndef D_LIBSSL_ARC4_DECRYPTOR_H
+#define D_LIBSSL_ARC4_DECRYPTOR_H
 
 #include "common.h"
 
@@ -48,7 +48,7 @@ namespace aria2 {
 
 class ARC4Decryptor {
 private:
-  LibsslARC4Context _ctx;
+  LibsslARC4Context ctx_;
 
   void handleError() const
   {
@@ -63,14 +63,14 @@ public:
 
   void init(const unsigned char* key, size_t keyLength)
   {
-    _ctx.init(key, keyLength, 0);
+    ctx_.init(key, keyLength, 0);
   }
 
   void decrypt(unsigned char* out, size_t outLength,
                const unsigned char* in, size_t inLength)
   {
     int soutLength = outLength;
-    if(!EVP_CipherUpdate(_ctx.getCipherContext(), out, &soutLength, in, inLength)) {
+    if(!EVP_CipherUpdate(ctx_.getCipherContext(), out, &soutLength, in, inLength)) {
       handleError();
     }
   }
@@ -78,4 +78,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_LIBSSL_ARC4_DECRYPTOR_H_
+#endif // D_LIBSSL_ARC4_DECRYPTOR_H
