@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,17 +32,25 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_METALINK_PARSER_STATE_H_
-#define _D_METALINK_PARSER_STATE_H_
+#ifndef D_METALINK_PARSER_STATE_H
+#define D_METALINK_PARSER_STATE_H
 
 #include "common.h"
-#include <map>
+
+#include <vector>
 #include <string>
 
 namespace aria2 {
 
 class MetalinkParserStateMachine;
 
+struct XmlAttr {
+  std::string localname;
+  std::string prefix;
+  std::string nsUri;
+  std::string value;
+};
+
 class MetalinkParserState
 {
 public:
@@ -50,16 +58,24 @@ public:
 
   virtual void beginElement
   (MetalinkParserStateMachine* stm,
-   const std::string& name,
-   const std::map<std::string, std::string>& attrs) = 0;
+   const std::string& localname,
+   const std::string& prefix,
+   const std::string& nsUri,
+   const std::vector<XmlAttr>& attrs) {}
   
   virtual void endElement
   (MetalinkParserStateMachine* stm,
-   const std::string& name, const std::string& characters) = 0;
+   const std::string& localname,
+   const std::string& prefix,
+   const std::string& nsUri,
+   const std::string& characters) {}
 
-  virtual bool needsCharactersBuffering() const = 0;
+  virtual bool needsCharactersBuffering() const
+  {
+    return false;
+  }
 };
 
 } // namespace aria2
 
-#endif // _D_METALINK_PARSER_STATE_H_
+#endif // D_METALINK_PARSER_STATE_H
