@@ -59,6 +59,7 @@
 #include "ServerStatMan.h"
 #include "FileAllocationEntry.h"
 #include "CheckIntegrityEntry.h"
+#include "TimeA2.h"
 #ifdef ENABLE_SSL
 # include "SocketCore.h"
 # include "TLSContext.h"
@@ -66,17 +67,14 @@
 
 namespace aria2 {
 
-#ifndef SA_RESETHAND
-# define SA_RESETHAND 0x80000000
-#endif // SA_RESETHAND
-
 namespace global {
 
 extern volatile sig_atomic_t globalHaltRequested;
 
 } // namespace global
 
-static void handler(int signal) {
+namespace {
+void handler(int signal) {
   if(
 #ifdef SIGHUP
      signal == SIGHUP ||
@@ -93,6 +91,7 @@ static void handler(int signal) {
     }
   }
 }
+} // namespace
 
 MultiUrlRequestInfo::MultiUrlRequestInfo
 (const std::vector<SharedHandle<RequestGroup> >& requestGroups,
@@ -128,7 +127,7 @@ downloadresultcode::RESULT MultiUrlRequestInfo::execute()
     if(!option_->blank(PREF_LOAD_COOKIES)) {
       File cookieFile(option_->get(PREF_LOAD_COOKIES));
       if(cookieFile.isFile()) {
-        e->getCookieStorage()->load(cookieFile.getPath());
+        e->getCookieStorage()->load(cookieFile.getPath(), Time().getTime());
         logger_->info("Loaded cookies from '%s'.",
                       cookieFile.getPath().c_str());
       } else {
@@ -160,12 +159,11 @@ downloadresultcode::RESULT MultiUrlRequestInfo::execute()
     }
     if(!option_->blank(PREF_CA_CERTIFICATE)) {
       if(!tlsContext->addTrustedCACertFile(option_->get(PREF_CA_CERTIFICATE))) {
-        logger_->warn(MSG_WARN_NO_CA_CERT);
+        logger_->info(MSG_WARN_NO_CA_CERT);
       }
     } else if(option_->getAsBool(PREF_CHECK_CERTIFICATE)) {
-      logger_->warn(MSG_WARN_NO_CA_CERT);
+      logger_->info(MSG_WARN_NO_CA_CERT);
     }
-
     if(option_->getAsBool(PREF_CHECK_CERTIFICATE)) {
       tlsContext->enablePeerVerification();
     }
