@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_NUMBER_DECORATOR_H_
-#define _D_NUMBER_DECORATOR_H_
+#ifndef D_NUMBER_DECORATOR_H
+#define D_NUMBER_DECORATOR_H
 
 #include "common.h"
 
@@ -52,4 +52,4 @@ public:
 
 } // namespace aria2;
 
-#endif // _D_NUMBER_DECORATOR_H_
+#endif // D_NUMBER_DECORATOR_H
