@@ -53,7 +53,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ALLOW_OVERWRITE,
                                     TEXT_ALLOW_OVERWRITE,
-                                    V_FALSE));
+                                    A2_V_FALSE));
     op->addTag(TAG_ADVANCED);
     op->addTag(TAG_FILE);
     handlers.push_back(op);
@@ -62,7 +62,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ALLOW_PIECE_LENGTH_CHANGE,
                                     TEXT_ALLOW_PIECE_LENGTH_CHANGE,
-                                    V_FALSE));
+                                    A2_V_FALSE));
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
   }
@@ -70,7 +70,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ALWAYS_RESUME,
                                     TEXT_ALWAYS_RESUME,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     op->addTag(TAG_FTP);
@@ -82,7 +82,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ASYNC_DNS,
                                     TEXT_ASYNC_DNS,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
@@ -92,7 +92,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_AUTO_FILE_RENAMING,
                                     TEXT_AUTO_FILE_RENAMING,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     op->addTag(TAG_FILE);
@@ -112,7 +112,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_CHECK_INTEGRITY,
                                     TEXT_CHECK_INTEGRITY,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG,
                                     'V'));
     op->addTag(TAG_BASIC);
@@ -126,7 +126,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_CONDITIONAL_GET,
                                     TEXT_CONDITIONAL_GET,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     op->addTag(TAG_HTTP);
@@ -144,7 +144,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_CONTINUE,
                                     TEXT_CONTINUE,
-                                    V_FALSE, // TODO ommit?
+                                    A2_V_FALSE, // TODO ommit?
                                     OptionHandler::NO_ARG,
                                     'c'));
     op->addTag(TAG_BASIC);
@@ -156,7 +156,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_DAEMON,
                                     TEXT_DAEMON,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::NO_ARG,
                                     'D')); // TODO ommit?
     op->addTag(TAG_ADVANCED);
@@ -178,7 +178,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_DISABLE_IPV6,
                                     TEXT_DISABLE_IPV6,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
@@ -192,12 +192,23 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->hide();
     handlers.push_back(op);
   }
+#ifdef ENABLE_ASYNC_DNS
+  {
+    SharedHandle<OptionHandler> op(new BooleanOptionHandler
+                                   (PREF_ENABLE_ASYNC_DNS6,
+                                    TEXT_ENABLE_ASYNC_DNS6,
+                                    A2_V_FALSE,
+                                    OptionHandler::OPT_ARG));
+    op->addTag(TAG_ADVANCED);
+    handlers.push_back(op);
+  }
+#endif // ENABLE_ASYNC_DNS
 #ifdef ENABLE_DIRECT_IO
   {
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ENABLE_DIRECT_IO,
                                     TEXT_ENABLE_DIRECT_IO,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     op->addTag(TAG_FILE);
@@ -209,7 +220,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ENABLE_XML_RPC,
                                     TEXT_ENABLE_XML_RPC,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_XML_RPC);
     handlers.push_back(op);
@@ -266,7 +277,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_FORCE_SEQUENTIAL,
                                     TEXT_FORCE_SEQUENTIAL,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG,
                                     'Z'));
     op->addTag(TAG_BASIC);
@@ -276,7 +287,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_HUMAN_READABLE,
                                     TEXT_HUMAN_READABLE,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
@@ -339,8 +350,11 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_MAX_CONNECTION_PER_SERVER,
                                     TEXT_MAX_CONNECTION_PER_SERVER,
                                     "1",
-                                    1, 4));
-    op->addTag(TAG_ADVANCED);
+                                    1, 16,
+                                    'x'));
+    op->addTag(TAG_BASIC);
+    op->addTag(TAG_FTP);
+    op->addTag(TAG_HTTP);
     handlers.push_back(op);
   }
   {
@@ -354,6 +368,15 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
   }
+  {
+    SharedHandle<OptionHandler> op(new NumberOptionHandler
+                                   (PREF_MAX_DOWNLOAD_RESULT,
+                                    TEXT_MAX_DOWNLOAD_RESULT,
+                                    "1000",
+                                    0));
+    op->addTag(TAG_ADVANCED);
+    handlers.push_back(op);
+  }
   {
     SharedHandle<OptionHandler> op(new UnitNumberOptionHandler
                                    (PREF_MAX_OVERALL_DOWNLOAD_LIMIT,
@@ -381,8 +404,9 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_MIN_SPLIT_SIZE,
                                     TEXT_MIN_SPLIT_SIZE,
                                     "20M",
-                                    1024*1024, 1024*1024*1024));
-    op->addTag(TAG_ADVANCED);
+                                    1024*1024, 1024*1024*1024,
+                                    'k'));
+    op->addTag(TAG_BASIC);
     op->addTag(TAG_FTP);
     op->addTag(TAG_HTTP);
     handlers.push_back(op);    
@@ -391,7 +415,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_NO_CONF,
                                     TEXT_NO_CONF,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::NO_ARG));
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
@@ -460,7 +484,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_PARAMETERIZED_URI,
                                     TEXT_PARAMETERIZED_URI,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG,
                                     'P'));  
     op->addTag(TAG_ADVANCED);
@@ -470,7 +494,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_QUIET,
                                     TEXT_QUIET,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG,
                                     'q'));
     op->addTag(TAG_ADVANCED);
@@ -481,7 +505,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_REALTIME_CHUNK_CHECKSUM,
                                     TEXT_REALTIME_CHUNK_CHECKSUM,
-                                    V_TRUE));
+                                    A2_V_TRUE));
     op->addTag(TAG_METALINK);
     handlers.push_back(op);
   }
@@ -490,7 +514,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_REMOVE_CONTROL_FILE,
                                     TEXT_REMOVE_CONTROL_FILE,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
@@ -508,7 +532,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_SELECT_LEAST_USED_HOST,
                                     NO_DEFAULT_VALUE,
-                                    V_TRUE));
+                                    A2_V_TRUE));
     op->hide();
     handlers.push_back(op);
   }
@@ -535,7 +559,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_XML_RPC_LISTEN_ALL,
                                     TEXT_XML_RPC_LISTEN_ALL,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_XML_RPC);
     handlers.push_back(op);
@@ -588,7 +612,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_DRY_RUN,
                                     TEXT_DRY_RUN,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_FTP);
     op->addTag(TAG_HTTP);
@@ -629,7 +653,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_NO_NETRC,
                                     TEXT_NO_NETRC,
-                                    V_FALSE, // TODO ommit?
+                                    A2_V_FALSE, // TODO ommit?
                                     OptionHandler::NO_ARG,
                                     'n'));
     op->addTag(TAG_FTP);
@@ -654,7 +678,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_REMOTE_TIME,
                                     TEXT_REMOTE_TIME,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG,
                                     'R'));
     op->addTag(TAG_FTP);
@@ -665,7 +689,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_REUSE_URI,
                                     TEXT_REUSE_URI,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_FTP);
     op->addTag(TAG_HTTP);
@@ -776,7 +800,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_CHECK_CERTIFICATE,
                                     TEXT_CHECK_CERTIFICATE,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_HTTP);
     op->addTag(TAG_HTTPS);
@@ -786,7 +810,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ENABLE_HTTP_KEEP_ALIVE,
                                     TEXT_ENABLE_HTTP_KEEP_ALIVE,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
@@ -795,7 +819,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ENABLE_HTTP_PIPELINING,
                                     TEXT_ENABLE_HTTP_PIPELINING,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
@@ -813,7 +837,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_HTTP_ACCEPT_GZIP,
                                     TEXT_HTTP_ACCEPT_GZIP,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
@@ -822,7 +846,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_HTTP_AUTH_CHALLENGE,
                                     TEXT_HTTP_AUTH_CHALLENGE,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
@@ -831,7 +855,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_HTTP_NO_CACHE,
                                     TEXT_HTTP_NO_CACHE,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
@@ -901,7 +925,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_USE_HEAD,
                                     TEXT_USE_HEAD,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
@@ -930,7 +954,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_FTP_PASV,
                                     TEXT_FTP_PASV,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG,
                                     'p'));
     op->addTag(TAG_FTP);
@@ -940,7 +964,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_FTP_REUSE_CONNECTION,
                                     TEXT_FTP_REUSE_CONNECTION,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_FTP);
     handlers.push_back(op);
@@ -1114,7 +1138,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_SHOW_FILES,
                                     TEXT_SHOW_FILES,
-                                    V_FALSE, // TODO ommit?
+                                    A2_V_FALSE, // TODO ommit?
                                     OptionHandler::NO_ARG,
                                     'S'));
     op->addTag(TAG_BASIC);
@@ -1129,11 +1153,21 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_BT_ENABLE_LPD,
                                     TEXT_BT_ENABLE_LPD,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
   }
+  {
+    SharedHandle<DefaultOptionHandler> op(new DefaultOptionHandler
+                                          (PREF_BT_EXCLUDE_TRACKER,
+                                           TEXT_BT_EXCLUDE_TRACKER,
+                                           NO_DESCRIPTION,
+                                           "URI,... "
+                                           "or *"));
+    op->addTag(TAG_BITTORRENT);
+    handlers.push_back(op);
+  }
   {
     SharedHandle<OptionHandler> op(new DefaultOptionHandler
                                    (PREF_BT_EXTERNAL_IP,
@@ -1156,7 +1190,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_BT_HASH_CHECK_SEED,
                                     TEXT_BT_HASH_CHECK_SEED,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
@@ -1194,7 +1228,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_BT_METADATA_ONLY,
                                     TEXT_BT_METADATA_ONLY,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
@@ -1228,7 +1262,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_BT_REQUIRE_CRYPTO,
                                     TEXT_BT_REQUIRE_CRYPTO,
-                                    V_FALSE));
+                                    A2_V_FALSE));
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
   }
@@ -1245,7 +1279,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_BT_SEED_UNVERIFIED,
                                     TEXT_BT_SEED_UNVERIFIED,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
@@ -1254,7 +1288,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_BT_SAVE_METADATA,
                                     TEXT_BT_SAVE_METADATA,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
@@ -1277,6 +1311,15 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->hide();
     handlers.push_back(op);
   }
+  {
+    SharedHandle<DefaultOptionHandler> op(new DefaultOptionHandler
+                                          (PREF_BT_TRACKER,
+                                           TEXT_BT_TRACKER,
+                                           NO_DESCRIPTION,
+                                           "URI,..."));
+    op->addTag(TAG_BITTORRENT);
+    handlers.push_back(op);
+  }
   {
     SharedHandle<NumberOptionHandler> op(new NumberOptionHandler
                                          (PREF_BT_TRACKER_CONNECT_TIMEOUT,
@@ -1314,6 +1357,16 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
   }
+  {
+    SharedHandle<OptionHandler> op(new HostPortOptionHandler
+                                   (PREF_DHT_ENTRY_POINT6,
+                                    TEXT_DHT_ENTRY_POINT6,
+                                    NO_DEFAULT_VALUE,
+                                    PREF_DHT_ENTRY_POINT_HOST6,
+                                    PREF_DHT_ENTRY_POINT_PORT6));
+    op->addTag(TAG_BITTORRENT);
+    handlers.push_back(op);
+  }
   {
     SharedHandle<OptionHandler> op(new DefaultOptionHandler
                                    (PREF_DHT_FILE_PATH,
@@ -1323,6 +1376,34 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
   }
+  {
+    SharedHandle<OptionHandler> op(new DefaultOptionHandler
+                                   (PREF_DHT_FILE_PATH6,
+                                    TEXT_DHT_FILE_PATH6,
+                                    util::getHomeDir()+"/.aria2/dht6.dat",
+                                    "/PATH/TO/DHT_DAT"));
+    op->addTag(TAG_BITTORRENT);
+    handlers.push_back(op);
+  }
+  {
+    SharedHandle<OptionHandler> op(new DefaultOptionHandler
+                                   (PREF_DHT_LISTEN_ADDR,
+                                    NO_DESCRIPTION,
+                                    NO_DEFAULT_VALUE));
+    op->hide();
+    op->addTag(TAG_BASIC);
+    op->addTag(TAG_BITTORRENT);
+    handlers.push_back(op);
+  }
+  {
+    SharedHandle<OptionHandler> op(new DefaultOptionHandler
+                                   (PREF_DHT_LISTEN_ADDR6,
+                                    TEXT_DHT_LISTEN_ADDR6,
+                                    NO_DEFAULT_VALUE));
+    op->addTag(TAG_BASIC);
+    op->addTag(TAG_BITTORRENT);
+    handlers.push_back(op);
+  }
   {
     SharedHandle<OptionHandler> op(new IntegerRangeOptionHandler
                                    (PREF_DHT_LISTEN_PORT,
@@ -1346,7 +1427,17 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ENABLE_DHT,
                                     TEXT_ENABLE_DHT,
-                                    V_TRUE,
+                                    A2_V_TRUE,
+                                    OptionHandler::OPT_ARG));
+    op->addTag(TAG_BASIC);
+    op->addTag(TAG_BITTORRENT);
+    handlers.push_back(op);
+  }
+  {
+    SharedHandle<OptionHandler> op(new BooleanOptionHandler
+                                   (PREF_ENABLE_DHT6,
+                                    TEXT_ENABLE_DHT6,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_BASIC);
     op->addTag(TAG_BITTORRENT);
@@ -1356,7 +1447,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ENABLE_PEER_EXCHANGE,
                                     TEXT_ENABLE_PEER_EXCHANGE,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
@@ -1365,8 +1456,8 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new ParameterOptionHandler
                                    (PREF_FOLLOW_TORRENT,
                                     TEXT_FOLLOW_TORRENT,
-                                    V_TRUE,
-                                    V_TRUE, V_MEM, V_FALSE));
+                                    A2_V_TRUE,
+                                    A2_V_TRUE, V_MEM, A2_V_FALSE));
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
   }
@@ -1472,8 +1563,8 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new ParameterOptionHandler
                                    (PREF_FOLLOW_METALINK,
                                     TEXT_FOLLOW_METALINK,
-                                    V_TRUE,
-                                    V_TRUE, V_MEM, V_FALSE));
+                                    A2_V_TRUE,
+                                    A2_V_TRUE, V_MEM, A2_V_FALSE));
     op->addTag(TAG_METALINK);
     handlers.push_back(op);
   }
@@ -1481,7 +1572,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_METALINK_ENABLE_UNIQUE_PROTOCOL,
                                     TEXT_METALINK_ENABLE_UNIQUE_PROTOCOL,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_METALINK);
     handlers.push_back(op);
