@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_P_STRING_SELECT_H_
-#define _D_P_STRING_SELECT_H_
+#ifndef D_P_STRING_SELECT_H
+#define D_P_STRING_SELECT_H
 
 #include "PStringDatum.h"
 #include "PStringSegment.h"
@@ -78,4 +78,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_P_STRING_SELECT_H_
+#endif // D_P_STRING_SELECT_H
