@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,17 +32,21 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_PEER_CONNECTION_H_
-#define _D_PEER_CONNECTION_H_
+#ifndef D_PEER_CONNECTION_H
+#define D_PEER_CONNECTION_H
 
 #include "common.h"
+
+#include <unistd.h>
+
 #include "SharedHandle.h"
 #include "SocketBuffer.h"
-#include <unistd.h>
+#include "Command.h"
 
 namespace aria2 {
 
 class Logger;
+class Peer;
 class SocketCore;
 class ARC4Encryptor;
 class ARC4Decryptor;
@@ -53,35 +57,42 @@ class ARC4Decryptor;
 
 class PeerConnection {
 private:
-  int32_t cuid;
-  SharedHandle<SocketCore> socket;
-  Logger* logger;
+  cuid_t cuid_;
+  SharedHandle<Peer> peer_;
+  SharedHandle<SocketCore> socket_;
+  Logger* logger_;
 
-  unsigned char resbuf[MAX_PAYLOAD_LEN];
-  size_t resbufLength;
-  size_t currentPayloadLength;
-  unsigned char lenbuf[4];
-  size_t lenbufLength;
+  unsigned char* resbuf_;
+  size_t resbufLength_;
+  size_t currentPayloadLength_;
+  unsigned char lenbuf_[4];
+  size_t lenbufLength_;
 
-  SocketBuffer _socketBuffer;
+  SocketBuffer socketBuffer_;
 
-  bool _encryptionEnabled;
-  SharedHandle<ARC4Encryptor> _encryptor;
-  SharedHandle<ARC4Decryptor> _decryptor;
+  bool encryptionEnabled_;
+  SharedHandle<ARC4Encryptor> encryptor_;
+  SharedHandle<ARC4Decryptor> decryptor_;
 
-  bool _prevPeek;
+  bool prevPeek_;
 
   void readData(unsigned char* data, size_t& length, bool encryption);
 
   ssize_t sendData(const unsigned char* data, size_t length, bool encryption);
 
 public:
-  PeerConnection(int32_t cuid, const SharedHandle<SocketCore>& socket);
+  PeerConnection
+  (cuid_t cuid,
+   const SharedHandle<Peer>& peer,
+   const SharedHandle<SocketCore>& socket);
 
   ~PeerConnection();
-  
-  // Returns the number of bytes written
-  ssize_t sendMessage(const unsigned char* data, size_t dataLength);
+
+  // Pushes data into send buffer. After this call, this object gets
+  // ownership of data, so caller must not delete or alter it.
+  void pushBytes(unsigned char* data, size_t len);
+
+  void pushStr(const std::string& data);
 
   bool receiveMessage(unsigned char* data, size_t& dataLength);
 
@@ -91,16 +102,29 @@ public:
    * In both cases, 'msg' is filled with received bytes and the filled length
    * is assigned to 'length'.
    */
-  bool receiveHandshake(unsigned char* data, size_t& dataLength, bool peek = false);
+  bool receiveHandshake
+  (unsigned char* data, size_t& dataLength, bool peek = false);
 
   void enableEncryption(const SharedHandle<ARC4Encryptor>& encryptor,
-			const SharedHandle<ARC4Decryptor>& decryptor);
+                        const SharedHandle<ARC4Decryptor>& decryptor);
 
   void presetBuffer(const unsigned char* data, size_t length);
 
   bool sendBufferIsEmpty() const;
   
   ssize_t sendPendingData();
+
+  const unsigned char* getBuffer() const
+  {
+    return resbuf_;
+  }
+
+  unsigned char* detachBuffer()
+  {
+    unsigned char* detachbuf = resbuf_;
+    resbuf_ = new unsigned char[MAX_PAYLOAD_LEN];
+    return detachbuf;
+  }
 };
 
 typedef SharedHandle<PeerConnection> PeerConnectionHandle;
@@ -108,4 +132,4 @@ typedef WeakHandle<PeerConnection> PeerConnectionWeakHandle;
 
 } // namespace aria2
 
-#endif // _D_PEER_CONNECTION_H_
+#endif // D_PEER_CONNECTION_H
