@@ -114,8 +114,9 @@ SharedHandle<Segment> SegmentMan::checkoutSegment
     return SharedHandle<Segment>();
   }
   if(logger_->debug()) {
-    logger_->debug("Attach segment#%d to CUID#%s.",
-                   piece->getIndex(), util::itos(cuid).c_str());
+    logger_->debug("Attach segment#%lu to CUID#%s.",
+                   static_cast<unsigned long>(piece->getIndex()),
+                   util::itos(cuid).c_str());
   }
   SharedHandle<Segment> segment;
   if(piece->getLength() == 0) {
@@ -126,11 +127,12 @@ SharedHandle<Segment> SegmentMan::checkoutSegment
   SegmentEntryHandle entry(new SegmentEntry(cuid, segment));
   usedSegmentEntries_.push_back(entry);
   if(logger_->debug()) {
-    logger_->debug("index=%d, length=%d, segmentLength=%d, writtenLength=%d",
-                   segment->getIndex(),
-                   segment->getLength(),
-                   segment->getSegmentLength(),
-                   segment->getWrittenLength());
+    logger_->debug("index=%lu, length=%lu, segmentLength=%lu,"
+                   " writtenLength=%lu",
+                   static_cast<unsigned long>(segment->getIndex()),
+                   static_cast<unsigned long>(segment->getLength()),
+                   static_cast<unsigned long>(segment->getSegmentLength()),
+                   static_cast<unsigned long>(segment->getWrittenLength()));
   }
   if(piece->getLength() > 0) {
     std::map<size_t, size_t>::iterator positr =
@@ -138,8 +140,9 @@ SharedHandle<Segment> SegmentMan::checkoutSegment
     if(positr != segmentWrittenLengthMemo_.end()) {
       const size_t writtenLength = (*positr).second;
       if(logger_->debug()) {
-        logger_->debug("writtenLength(in memo)=%d, writtenLength=%d",
-                       writtenLength, segment->getWrittenLength());
+        logger_->debug("writtenLength(in memo)=%lu, writtenLength=%lu",
+                       static_cast<unsigned long>(writtenLength),
+                       static_cast<unsigned long>(segment->getWrittenLength()));
       }
       //  If the difference between cached writtenLength and segment's
       //  writtenLength is less than one block, we assume that these
@@ -247,13 +250,15 @@ SharedHandle<Segment> SegmentMan::getCleanSegmentIfOwnerIsIdle
 void SegmentMan::cancelSegment(const SharedHandle<Segment>& segment)
 {
   if(logger_->debug()) {
-    logger_->debug("Canceling segment#%d", segment->getIndex());
+    logger_->debug("Canceling segment#%lu",
+                   static_cast<unsigned long>(segment->getIndex()));
   }
   pieceStorage_->cancelPiece(segment->getPiece());
   segmentWrittenLengthMemo_[segment->getIndex()] = segment->getWrittenLength();
   if(logger_->debug()) {
-    logger_->debug("Memorized segment index=%u, writtenLength=%u",
-                   segment->getIndex(), segment->getWrittenLength());
+    logger_->debug("Memorized segment index=%lu, writtenLength=%lu",
+                   static_cast<unsigned long>(segment->getIndex()),
+                   static_cast<unsigned long>(segment->getWrittenLength()));
   }
 }
 
@@ -301,6 +306,7 @@ void SegmentMan::eraseSegmentWrittenLengthMemo()
   segmentWrittenLengthMemo_.clear();
 }
 
+namespace {
 class FindSegmentEntry {
 private:
   SharedHandle<Segment> segment_;
@@ -312,6 +318,7 @@ public:
     return segmentEntry->segment->getIndex() == segment_->getIndex();
   }
 };
+} // namespace
 
 bool SegmentMan::completeSegment
 (cuid_t cuid, const SharedHandle<Segment>& segment) {
@@ -363,7 +370,7 @@ SharedHandle<PeerStat> SegmentMan::getPeerStat(cuid_t cuid) const
   return SharedHandle<PeerStat>();
 }
 
-
+namespace {
 class PeerStatHostProtoEqual {
 private:
   const SharedHandle<PeerStat>& peerStat_;
@@ -377,6 +384,7 @@ public:
       peerStat_->getProtocol() == p->getProtocol();
   }
 };
+} // namespace
 
 void SegmentMan::updateFastestPeerStat(const SharedHandle<PeerStat>& peerStat)
 {
@@ -429,6 +437,7 @@ void SegmentMan::updateDownloadSpeedFor(const SharedHandle<PeerStat>& pstat)
   peerStatDlspdMap_[pstat->getCuid()] = newspd;
 }
 
+namespace {
 class PeerStatDownloadLengthOperator {
 public:
   uint64_t operator()(uint64_t total, const SharedHandle<PeerStat>& ps)
@@ -436,6 +445,7 @@ public:
     return ps->getSessionDownloadLength()+total;
   }
 };
+} // namespace
 
 uint64_t SegmentMan::calculateSessionDownloadLength() const
 {
