@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_SELECT_EVENT_POLL_H_
-#define _D_SELECT_EVENT_POLL_H_
+#ifndef D_SELECT_EVENT_POLL_H
+#define D_SELECT_EVENT_POLL_H
 
 #include "EventPoll.h"
 
@@ -194,4 +194,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_SELECT_EVENT_POLL_H_
+#endif // D_SELECT_EVENT_POLL_H
