@@ -32,14 +32,15 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_SINGLE_FILE_ALLOCATION_ITERATOR_H_
-#define _D_SINGLE_FILE_ALLOCATION_ITERATOR_H_
+#ifndef D_SINGLE_FILE_ALLOCATION_ITERATOR_H
+#define D_SINGLE_FILE_ALLOCATION_ITERATOR_H
 
 #include "FileAllocationIterator.h"
 
 namespace aria2 {
 
 class BinaryStream;
+class Logger;
 
 class SingleFileAllocationIterator:public FileAllocationIterator
 {
@@ -51,6 +52,8 @@ private:
   uint64_t totalLength_;
 
   unsigned char* buffer_;
+
+  Logger* logger_;
 public:
   SingleFileAllocationIterator(BinaryStream* stream, off_t offset, uint64_t totalLength);
 
@@ -78,4 +81,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_SINGLE_FILE_ALLOCATION_ITERATOR_H_
+#endif // D_SINGLE_FILE_ALLOCATION_ITERATOR_H
