@@ -42,6 +42,9 @@
 #include "RequestGroup.h"
 #include "DownloadContext.h"
 #include "Command.h"
+#include "RequestGroupMan.h"
+#include "CheckIntegrityEntry.h"
+#include "ServerStatMan.h"
 
 namespace aria2 {
 
@@ -56,16 +59,36 @@ void StreamFileAllocationEntry::prepareForNextAction
 (std::vector<Command*>& commands,
  DownloadEngine* e)
 {
-  _requestGroup->getDownloadContext()->resetDownloadStartTime();
-  if(_nextCommand) {
+  // For DownloadContext::resetDownloadStartTime(), see also
+  // RequestGroup::createInitialCommand()
+  getRequestGroup()->getDownloadContext()->resetDownloadStartTime();
+  if(getNextCommand()) {
+    // Reset download start time of PeerStat because it is started
+    // before file allocation begins.
+    const SharedHandle<DownloadContext>& dctx =
+      getRequestGroup()->getDownloadContext();
+    const std::vector<SharedHandle<FileEntry> >& fileEntries =
+      dctx->getFileEntries();
+    for(std::vector<SharedHandle<FileEntry> >::const_iterator i =
+          fileEntries.begin(), eoi = fileEntries.end(); i != eoi; ++i) {
+      const std::deque<SharedHandle<Request> >& reqs =
+        (*i)->getInFlightRequests();
+      for(std::deque<SharedHandle<Request> >::const_iterator j =
+            reqs.begin(), eoj = reqs.end(); j != eoj; ++j) {
+        const SharedHandle<PeerStat>& peerStat = (*j)->getPeerStat();
+        if(!peerStat.isNull()) {
+          peerStat->downloadStart();
+        }
+      }
+    }
     // give _nextCommand a chance to execute in the next execution loop.
-    _nextCommand->setStatus(Command::STATUS_ONESHOT_REALTIME);
+    getNextCommand()->setStatus(Command::STATUS_ONESHOT_REALTIME);
     e->setNoWait(true);
     commands.push_back(popNextCommand());
     // try remaining uris
-    _requestGroup->createNextCommandWithAdj(commands, e, -1);
+    getRequestGroup()->createNextCommandWithAdj(commands, e, -1);
   } else {
-    _requestGroup->createNextCommandWithAdj(commands, e, 0);
+    getRequestGroup()->createNextCommandWithAdj(commands, e, 0);
   }
 }
 
