@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_UT_METADATA_REQUEST_EXTENSION_MESSAGE_H_
-#define _D_UT_METADATA_REQUEST_EXTENSION_MESSAGE_H_
+#ifndef D_UT_METADATA_REQUEST_EXTENSION_MESSAGE_H
+#define D_UT_METADATA_REQUEST_EXTENSION_MESSAGE_H
 
 #include "UTMetadataExtensionMessage.h"
 
@@ -85,4 +85,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_UT_METADATA_REQUEST_EXTENSION_MESSAGE_H_
+#endif // D_UT_METADATA_REQUEST_EXTENSION_MESSAGE_H
