@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,20 +32,20 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_XML_RPC_METHOD_H_
-#define _D_XML_RPC_METHOD_H_
+#ifndef D_XML_RPC_METHOD_H
+#define D_XML_RPC_METHOD_H
 
 #include "common.h"
 
 #include <string>
 
 #include "SharedHandle.h"
+#include "ValueBase.h"
 
 namespace aria2 {
 
 class DownloadEngine;
 class OptionParser;
-class BDE;
 class Logger;
 class Option;
 class Exception;
@@ -63,34 +63,40 @@ struct XmlRpcResponse;
 // subclass. If you add new XmlRpcMethod subclass, don't forget to add
 // it to XmlRpcMethodFactory.
 class XmlRpcMethod {
+private:
+  SharedHandle<OptionParser> optionParser_;
+
+  Logger* logger_;
 protected:
-  SharedHandle<OptionParser> _optionParser;
-
-  Logger* _logger;
-
   // Subclass must implement this function to fulfil XmlRpcRequest
   // req.  The return value of this method is used as a return value
   // of XML-RPC request.
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e) = 0;
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e) = 0;
 
-  void gatherRequestOption(const SharedHandle<Option>& option,
-			   const BDE& optionsDict);
+  void gatherRequestOption
+  (const SharedHandle<Option>& option, const Dict* optionsDict);
 
-  void gatherChangeableOption(const SharedHandle<Option>& option,
-			      const BDE& optionDict);
+  void gatherChangeableOption
+  (const SharedHandle<Option>& option, const Dict* optionDict);
 
   // Copy options which is changeable in XML-RPC changeOption command
   // to dest.
   void applyChangeableOption(Option* dest, Option* src) const;
 
   void gatherChangeableGlobalOption(const SharedHandle<Option>& option,
-				    const BDE& optionDict);
+                                    const Dict* optionDict);
 
   // Copy options which is changeable in XML-RPC changeGlobalOption
   // command to dest.
   void applyChangeableGlobalOption(Option* dest, Option* src) const;
 
-  BDE createErrorResponse(const Exception& e);
+  SharedHandle<ValueBase> createErrorResponse(const Exception& e);
+
+  const SharedHandle<OptionParser>& getOptionParser() const
+  {
+    return optionParser_;
+  }
 public:
   XmlRpcMethod();
 
@@ -105,4 +111,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_XML_RPC_METHOD_H_
+#endif // D_XML_RPC_METHOD_H
