@@ -150,10 +150,12 @@ public:
 
 CPPUNIT_TEST_SUITE_REGISTRATION(XmlRpcMethodTest);
 
-static std::string getString(const Dict* dict, const std::string& key)
+namespace {
+std::string getString(const Dict* dict, const std::string& key)
 {
   return asString(dict->get(key))->s();
 }
+} // namespace
 
 void XmlRpcMethodTest::testAddUri()
 {
@@ -587,8 +589,8 @@ void XmlRpcMethodTest::testTellStatus_withoutGid()
   CPPUNIT_ASSERT_EQUAL(1, res.code);
 }
 
-static void addUri(const std::string& uri,
-                   const SharedHandle<DownloadEngine>& e)
+namespace {
+void addUri(const std::string& uri, const SharedHandle<DownloadEngine>& e)
 {
   AddUriXmlRpcMethod m;
   XmlRpcRequest req(AddUriXmlRpcMethod::getMethodName(), List::g());
@@ -597,10 +599,11 @@ static void addUri(const std::string& uri,
   req.params->append(urisParam);
   CPPUNIT_ASSERT_EQUAL(0, m.execute(req, e.get()).code);
 }
+} // namespace
 
 #ifdef ENABLE_BITTORRENT
-
-static void addTorrent
+namespace {
+void addTorrent
 (const std::string& torrentFile, const SharedHandle<DownloadEngine>& e)
 {
   AddTorrentXmlRpcMethod m;
@@ -608,7 +611,7 @@ static void addTorrent
   req.params->append(readFile(torrentFile));
   XmlRpcResponse res = m.execute(req, e.get());
 }
-
+} // namespace
 #endif // ENABLE_BITTORRENT
 
 void XmlRpcMethodTest::testTellWaiting()
@@ -728,13 +731,21 @@ void XmlRpcMethodTest::testGatherStoppedDownload()
   d->followedBy = followedBy;
   d->belongsTo = 2;
   SharedHandle<Dict> entry = Dict::g();
-  gatherStoppedDownload(entry, d);
+  std::vector<std::string> keys;
+  gatherStoppedDownload(entry, d, keys);
 
   const List* followedByRes = asList(entry->get("followedBy"));
   CPPUNIT_ASSERT_EQUAL(std::string("3"), asString(followedByRes->get(0))->s());
   CPPUNIT_ASSERT_EQUAL(std::string("4"), asString(followedByRes->get(1))->s());
   CPPUNIT_ASSERT_EQUAL(std::string("2"),
                        asString(entry->get("belongsTo"))->s());
+
+  keys.push_back("gid");
+
+  entry = Dict::g();
+  gatherStoppedDownload(entry, d, keys);
+  CPPUNIT_ASSERT_EQUAL((size_t)1, entry->size());
+  CPPUNIT_ASSERT(entry->containsKey("gid"));
 }
 
 void XmlRpcMethodTest::testGatherProgressCommon()
@@ -754,7 +765,8 @@ void XmlRpcMethodTest::testGatherProgressCommon()
   group->belongsTo(2);
 
   SharedHandle<Dict> entry = Dict::g();
-  gatherProgressCommon(entry, group);
+  std::vector<std::string> keys;
+  gatherProgressCommon(entry, group, keys);
   
   const List* followedByRes = asList(entry->get("followedBy"));
   CPPUNIT_ASSERT_EQUAL(util::itos(followedBy[0]->getGID()),
@@ -775,6 +787,14 @@ void XmlRpcMethodTest::testGatherProgressCommon()
                         ->get("uri"))
                        ->s());
   CPPUNIT_ASSERT_EQUAL(std::string("/tmp"), asString(entry->get("dir"))->s());
+
+  keys.push_back("gid");
+  entry = Dict::g();
+  gatherProgressCommon(entry, group, keys);
+
+  CPPUNIT_ASSERT_EQUAL((size_t)1, entry->size());
+  CPPUNIT_ASSERT(entry->containsKey("gid"));
+  
 }
 
 #ifdef ENABLE_BITTORRENT
@@ -995,7 +1015,7 @@ void XmlRpcMethodTest::testPause()
     "http://url3",
   };
   std::vector<std::string> uris(vbegin(URIS), vend(URIS));
-  option_->put(PREF_FORCE_SEQUENTIAL, V_TRUE);
+  option_->put(PREF_FORCE_SEQUENTIAL, A2_V_TRUE);
   std::vector<SharedHandle<RequestGroup> > groups;
   createRequestGroupForUri(groups, option_, uris);
   CPPUNIT_ASSERT_EQUAL((size_t)3, groups.size());  
